Package: slopes
Title: Calculate Slopes of Roads, Rivers and Trajectories
Version: 1.0.2
Authors@R: c(
    person("Robin", "Lovelace", email = "rob00x@gmail.com", role = c("aut", "cre", "cph"),
      comment = c(ORCID = "0000-0001-5679-6536")),
    person("Rosa", "Félix", email = "rosamfelix@tecnico.ulisboa.pt", role = c("aut"), 
      comment = c(ORCID = "0000-0002-5642-6006")),
    person("Joey", "Talbot", email = "j.d.talbot@leeds.ac.uk", role = c("aut"), 
      comment = c(ORCID = "0000-0002-6520-4560")),
    person("Gonçalo", "Matos", email = "goncaloafmatos@tecnico.ulisboa.pt", role = c("aut"),
      comment = c(ORCID = "0009-0001-3489-1732")),
    person("Dan", "Olner", role = c("rev"), comment = "Dan reviewed the package for rOpenSci, see https://github.com/ropensci/software-review/issues/420#issuecomment-857662657 "),
    person("Andy", "Teucher", role = c("rev"), comment = "Andy reviewed the package for rOpenSci, see https://github.com/ropensci/software-review/issues/420#issuecomment-858231647 ")
  )
Description: Calculates the slope (longitudinal gradient or steepness)
  of linear geographic features such as roads (for more details, see Ariza-López et al. (2019) 
  <doi:10.1038/s41597-019-0147-x>) and rivers (for more details, see Cohen et al. (2018) 
  <doi:10.1016/j.jhydrol.2018.06.066>). It can use local Digital Elevation Model (DEM) 
  data or download DEM data via the 'ceramic' package. The package also provides functions 
  to add elevation data to linestrings and visualize elevation profiles.
License: GPL-3
URL: https://github.com/ropensci/slopes/,
        https://docs.ropensci.org/slopes/
BugReports: https://github.com/ropensci/slopes/issues
Encoding: UTF-8
LazyData: true
Imports: sf, terra, methods, pbapply, geodist, colorspace
Depends: R (>= 2.10)
Suggests: knitr, rmarkdown, ceramic, bookdown, covr, testthat,
        osmextract, stplanr, dplyr, tmap, leaflet, bench, rlang
Config/Needs/website: generics
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-16 21:27:59 UTC; robin
Author: Robin Lovelace [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-5679-6536>),
  Rosa Félix [aut] (ORCID: <https://orcid.org/0000-0002-5642-6006>),
  Joey Talbot [aut] (ORCID: <https://orcid.org/0000-0002-6520-4560>),
  Gonçalo Matos [aut] (ORCID: <https://orcid.org/0009-0001-3489-1732>),
  Dan Olner [rev] (Dan reviewed the package for rOpenSci, see
    https://github.com/ropensci/software-review/issues/420#issuecomment-857662657),
  Andy Teucher [rev] (Andy reviewed the package for rOpenSci, see
    https://github.com/ropensci/software-review/issues/420#issuecomment-858231647)
Maintainer: Robin Lovelace <rob00x@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-17 07:20:08 UTC
