# Generated by roxygen2: do not edit by hand

export(dem_lisbon)
export(elevation_add)
export(elevation_extract)
export(elevation_get)
export(plot_dz)
export(plot_slope)
export(route_to_segments)
export(sequential_dist)
export(slope_distance)
export(slope_distance_mean)
export(slope_distance_weighted)
export(slope_matrices)
export(slope_matrix)
export(slope_matrix_mean)
export(slope_matrix_to_raster)
export(slope_matrix_weighted)
export(slope_raster)
export(slope_vector)
export(slope_xyz)
export(slope_xyz_simple)
export(slopes_palette)
