% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{cyclestreets_route}
\alias{cyclestreets_route}
\title{Cycle route data}
\format{
An sf object
}
\usage{
cyclestreets_route
}
\description{
Cycle route data
}
\keyword{datasets}
