% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{lisbon_road_segment}
\alias{lisbon_road_segment}
\title{Lisbon road segment}
\format{
An sf object
}
\usage{
lisbon_road_segment
}
\description{
Lisbon road segment
}
\keyword{datasets}
