% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/slope_get.R
\name{sf_mid_ext_lonlat}
\alias{sf_mid_ext_lonlat}
\title{Extract midpoint and extent from routes in lonlat}
\usage{
sf_mid_ext_lonlat(routes)
}
\arguments{
\item{routes}{An sf object containing linestring geometries}
}
\value{
A list with midpoint coordinates and width/height dimensions
}
\description{
Internal helper function to get midpoint and extent of routes in lon/lat coordinates.
}
