% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{lisbon_route_xyz_mapbox}
\alias{lisbon_route_xyz_mapbox}
\title{Lisbon route XYZ}
\format{
An sf object
}
\usage{
lisbon_route_xyz_mapbox
}
\description{
Lisbon route XYZ
}
\keyword{datasets}
