% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{magnolia_xy}
\alias{magnolia_xy}
\title{Magnolia coordinates}
\format{
A data frame
}
\usage{
magnolia_xy
}
\description{
Magnolia coordinates
}
\keyword{datasets}
